==> org.eclipse.rap.rwt.source_2.3.0.20140127-1357.jar: rwt/remote/handler/TabItemHandler.js <==
/*******************************************************************************
 * Copyright (c) 2011, 2013 EclipseSource and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    EclipseSource - initial API and implementation
 ******************************************************************************/

rwt.remote.HandlerRegistry.add( "rwt.widgets.TabItem", {

  factory : function( properties ) {
    var result = rwt.widgets.util.TabUtil.createTabItem( properties.id,
                                                         properties.parent,
                                                         properties.index );

    rwt.remote.HandlerUtil.callWithTarget( properties.parent, function( parent ) {
      rwt.remote.HandlerUtil.addDestroyableChild( parent, result );
      result.setUserData( "protocolParent", parent );
    } );
    return result;
  },

  destructor : function( widget ) {
    rwt.widgets.util.TabUtil.releaseTabItem( widget );
    var parent = widget.getUserData( "protocolParent" );
    if( parent ) {
      rwt.remote.HandlerUtil.removeDestroyableChild( parent, widget );
    }
  },

  properties : [
    "text",
    "mnemonicIndex",
    "image",
    "control",
    "toolTipMarkupEnabled",
    "toolTip",
    "customVariant"
  ],

  propertyHandler : {
    "image" : function( widget, value ) {
      if( value === null ) {
        widget.setIcon( null );
      } else {
        widget.setIcon( value[ 0 ] );
      }
    },
    "control" : function( widget, value ) {
      if( value !== null ) {
        rwt.remote.HandlerUtil.callWithTarget( value, function( control ) {
          var widgetManager = rwt.remote.WidgetManager.getInstance();
          var id = widgetManager.findIdByWidget( widget ) + "pg";
          rwt.remote.HandlerUtil.callWithTarget( id, function( parent ) {
            control.setParent( parent );
          } );
        } );
      }
    },
    "toolTipMarkupEnabled" : rwt.remote.HandlerUtil.getControlPropertyHandler( "toolTipMarkupEnabled" ),
    "toolTip" : rwt.remote.HandlerUtil.getControlPropertyHandler( "toolTip" )
  }

} );

==> org.eclipse.rap.rwt.source_2.3.2.20150128-1013.jar: rwt/remote/handler/TabItemHandler.js <==
/*******************************************************************************
 * Copyright (c) 2011, 2014 EclipseSource and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    EclipseSource - initial API and implementation
 ******************************************************************************/

rwt.remote.HandlerRegistry.add( "rwt.widgets.TabItem", {

  factory : function( properties ) {
    var result = rwt.widgets.util.TabUtil.createTabItem( properties.id,
                                                         properties.parent,
                                                         properties.index );

    rwt.remote.HandlerUtil.callWithTarget( properties.parent, function( parent ) {
      rwt.remote.HandlerUtil.addDestroyableChild( parent, result );
      result.setUserData( "protocolParent", parent );
    } );
    return result;
  },

  destructor : function( widget ) {
    var control = widget.getUserData( "control" );
    if( control ) {
      if( !control._isInGlobalDisposeQueue ) {
        control.setParent( null );
      }
      widget.setUserData( "control", null );
    }
    rwt.widgets.util.TabUtil.releaseTabItem( widget );
    var parent = widget.getUserData( "protocolParent" );
    if( parent ) {
      rwt.remote.HandlerUtil.removeDestroyableChild( parent, widget );
    }
  },

  properties : [
    "text",
    "mnemonicIndex",
    "image",
    "control",
    "toolTipMarkupEnabled",
    "toolTip",
    "customVariant"
  ],

  propertyHandler : {
    "image" : function( widget, value ) {
      if( value === null ) {
        widget.setIcon( null );
      } else {
        widget.setIcon( value[ 0 ] );
      }
    },
    "control" : function( widget, value ) {
      if( value !== null ) {
        rwt.remote.HandlerUtil.callWithTarget( value, function( control ) {
          var widgetManager = rwt.remote.WidgetManager.getInstance();
          var id = widgetManager.findIdByWidget( widget ) + "pg";
          rwt.remote.HandlerUtil.callWithTarget( id, function( parent ) {
            control.setParent( parent );
            widget.setUserData( "control", control );
          } );
        } );
      }
    },
    "toolTipMarkupEnabled" : rwt.remote.HandlerUtil.getControlPropertyHandler( "toolTipMarkupEnabled" ),
    "toolTip" : rwt.remote.HandlerUtil.getControlPropertyHandler( "toolTip" )
  }

} );
